Welcome to npTDMS's documentation
=================================

npTDMS is a cross-platform Python package for reading and writing TDMS files as produced by LabVIEW,
and is built on top of the `numpy <http://www.numpy.org/>`__ package.
Data is read from TDMS files as numpy arrays,
and npTDMS also allows writing numpy arrays to TDMS files.

Contents
========

.. toctree::
    quickstart
    reading
    writing
    apireference
    tdmsinfo
    limitations
